@@ -6,13 +6,12 @@ BEGIN {
   $Path::IsDev::Heuristic::AUTHORITY = 'cpan:KENTNL';
 }
 {
-  $Path::IsDev::Heuristic::VERSION = '0.4.0';
+  $Path::IsDev::Heuristic::VERSION = '0.5.0';
 }
 
 # ABSTRACT: Heuristic Base class
 
 
-sub _path    { require Path::Tiny;   goto &Path::Tiny::path }
 sub _croak   { require Carp;         goto &Carp::croak }
 sub _blessed { require Scalar::Util; goto &Scalar::Util::blessed }
 sub _debug   { require Path::IsDev;  goto &Path::IsDev::debug }
@@ -27,43 +26,51 @@ sub name {
 
 
 sub _file_matches {
-  my ( $self, $path ) = @_;
-  my $root = _path($path);
+  my ( $self, $result_object ) = @_;
+  my $root = $result_object->path;
   for my $file ( $self->files ) {
     my $stat = $root->child($file);
-    next unless -e $stat;
-    next unless -f $stat;
-    _debug("$stat exists for $self");
-    return 1;
+    if ( -e $stat and -f $stat ) {
+      _debug("$stat exists for $self");
+      $result_object->add_reason( $self, 1, { 'file_exists?' => $stat } );
+      $result_object->result(1);
+      return 1;
+    }
+    $result_object->add_reason( $self, 0, { 'file_exists?' => $stat } );
   }
+  $result_object->result(undef);
   return;
 }
 
 
 sub _dir_matches {
-  my ( $self, $path ) = @_;
-  my $root = _path($path);
+  my ( $self, $result_object ) = @_;
+  my $root = $result_object->path;
   for my $file ( $self->dirs ) {
     my $stat = $root->child($file);
-    next unless -e $stat;
-    next unless -d $stat;
-    _debug( "$stat exists for" . $self->name );
-    return 1;
+    if ( -e $stat and -d $stat ) {
+      _debug( "$stat exists for" . $self->name );
+      $result_object->add_reason( $self, 1, { 'dir_exists?' => $stat } );
+      $result_object->result(1);
+      return 1;
+    }
+    $result_object->add_reason( $self, 0, { 'dir_exists?' => $stat } );
   }
+  $result_object->result(undef);
   return;
 }
 
 
 sub matches {
-  my ( $self, $path ) = @_;
+  my ( $self, $result_object ) = @_;
   if ( not $self->can('files') and not $self->can('dirs') ) {
     return _croak("Heuristic $self did not implement one of : matches, files, dirs");
   }
   if ( $self->can('files') ) {
-    return 1 if $self->_file_matches($path);
+    return 1 if $self->_file_matches($result_object);
   }
   if ( $self->can('dirs') ) {
-    return 1 if $self->_dir_matches($path);
+    return 1 if $self->_dir_matches($result_object);
   }
   return;
 }
@@ -82,7 +89,7 @@ Path::IsDev::Heuristic - Heuristic Base class
 
 =head1 VERSION
 
-version 0.4.0
+version 0.5.0
 
 =head1 METHODS
 
@@ -99,7 +106,7 @@ with the C<PIDH> prefix removed:
 
 Determines if the current heuristic matches a given path
 
-    my $result = $heuristic->matches( $path );
+    my $matched = $heuristic->matches( $result_object );
 
 The default implementation takes values from C<< ->files >> and C<< ->dirs >>
 and returns true as soon as any match satisfies.
@@ -111,14 +118,14 @@ and returns true as soon as any match satisfies.
 Glue layer between C<< ->matches >> and C<< ->files >>
 
     # iterate $heuristic->files looking for a match
-    $heurisitic->_file_matches($path);
+    $heurisitic->_file_matches( $result_object );
 
 =head2 C<_dir_matches>
 
 Glue layer between C<< ->matches >> and C<< ->dirs >>
 
     # iterate $heuristic->dirs looking for a match
-    $heurisitic->_dir_matches($path);
+    $heurisitic->_dir_matches( $result_object );
 
 =begin MetaPOD::JSON v1.1.0
 
